import typing

from .StructuralDampingByFrequencyComponent import StructuralDampingByFrequencyComponent

StructuralDampingByFrequencyComponentArray = typing.List[StructuralDampingByFrequencyComponent]
